-- motorSound.lua
-- motor sound under load
--
-- Author RivalBomb
-- 30/08/2015

motorSound = {};

function motorSound.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Motorized, specializations);
end;

function motorSound:load(xmlFile)
	if self.isClient then
		self.sampleMotorRunLast = Utils.loadSample(xmlFile, {}, "vehicle.motorSoundRunLast", nil, self.baseDirectory, self.components[1].node);
		--self.motorSoundRunLastPitchScale = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.motorSoundRunLast#pitchScale"), 0.05);
		self.motorSoundRunLastPitchMax = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.motorSoundRunLast#pitchMax"), 2.0);
		
		local pitchCurveRunLast = AnimCurve:new(linearInterpolator1);
        --pitchCurveRunLast:addKeyframe({v=self.sampleMotorRunLast.pitchOffset, time = self.motor.minRpm});
		--pitchCurveRunLast:addKeyframe({v=self.motorSoundRunLastPitchMax, time = self.motor.maxRpm});
        pitchCurveRunLast:addKeyframe({v=self.sampleMotorRunLast.pitchOffset, time = 0});
		pitchCurveRunLast:addKeyframe({v=self.motorSoundRunLastPitchMax, time = 1});
		self.pitchCurveRunLast = pitchCurveRunLast;
		local volCurveIdle = AnimCurve:new(linearInterpolator1);
        volCurveIdle:addKeyframe({v=self.sampleMotor.volume, time = self.motor.minRpm});
        volCurveIdle:addKeyframe({v=self.sampleMotor.volume/3, time = self.motor.minRpm+500});
		volCurveIdle:addKeyframe({v=0.01, time = self.motor.maxRpm});
		self.volCurveIdle = volCurveIdle;
		local volCurveRun = AnimCurve:new(linearInterpolator1);
        volCurveRun:addKeyframe({v=0.01, time = self.motor.minRpm});
        volCurveRun:addKeyframe({v=self.sampleMotorRun.volume, time = self.motor.minRpm+500});
		volCurveRun:addKeyframe({v=self.sampleMotorRun.volume, time = self.motor.maxRpm});
		self.volCurveRun = volCurveRun;
	end;
	self.motorRunLastVolS = 0;
end;
function motorSound:delete()
	if self.sampleMotorRunLast ~= nil then
		Utils.deleteSample(self.sampleMotorRunLast);
	end;
end;
function motorSound:mouseEvent(posX, posY, isDown, isUp, button)
end;
function motorSound:keyEvent(unicode, sym, modifier, isDown)
end;
function motorSound:update(dt)
	if self.isMotorStarted and self.isEntered then
        if self.isClient then
			if self:getIsActiveForSound() and not Utils.isSamplePlaying(self.sampleMotorRunLast, 1.5*dt) then
				Utils.playSample(self.sampleMotorRunLast, 0, 0, nil);
			end;
			if self.motorRunLastVolS < self.motor.motorLoad then
				self.motorRunLastVolS = self.motorRunLastVolS+(dt/2000);
			elseif self.motorRunLastVolS > self.motor.motorLoad then
				self.motorRunLastVolS = self.motorRunLastVolS-(dt/2000);
			end;
			local rpmRunVolume = Utils.clamp(self.motorRunLastVolS, 0.0, 1.0);
		
			local multi = 1;
			if self.cameras[self.camIndex].isInside then
				multi = 0.25;
			else
				multi = 0.9;
			end;
			Utils.setSamplePitch(self.sampleMotorRunLast, self.pitchCurveRunLast:get(self.motorRunLastVolS)); -- self.motor.lastMotorRpm
			Utils.setSampleVolume(self.sampleMotorRunLast, rpmRunVolume*self.sampleMotorRunLast.volume*multi);
			self.sampleMotor.volume = self.volCurveIdle:get(self.motor.lastMotorRpm);
			Utils.setSampleVolume(self.sampleMotor, self.volCurveIdle:get(self.motor.lastMotorRpm));
			Utils.setSampleVolume(self.sampleMotorRun, self.volCurveRun:get(self.motor.lastMotorRpm));
		end;
	else
		if self.isClient then
			Utils.stopSample(self.sampleMotorRunLast);
		end;
	end;
end;
function motorSound:updateTick(dt)
end;
function motorSound:draw()	
end;